@@ -8,7 +8,6 @@ CREATE TABLE dc_blog (
     blog_name VARCHAR(255) NOT NULL,
     blog_desc TEXT,
     blog_status SMALLINT DEFAULT 1 NOT NULL,
-    INDEX dc_blog_pkey (blog_id),
     PRIMARY KEY (blog_id)
 );
 
@@ -27,6 +26,68 @@ CREATE TABLE dc_category (
     PRIMARY KEY (cat_id)
 );
 
+-- DROP TABLE IF EXISTS dc_user;
+CREATE TABLE dc_user (
+    user_id VARCHAR(32) NOT NULL,
+    user_super SMALLINT,
+    user_status SMALLINT DEFAULT 1 NOT NULL,
+    user_pwd VARCHAR(40) NOT NULL,
+    user_change_pwd SMALLINT DEFAULT 0 NOT NULL,
+    user_recover_key VARCHAR(32) DEFAULT NULL,
+    user_name VARCHAR(255) DEFAULT NULL,
+    user_firstname VARCHAR(255) DEFAULT NULL,
+    user_displayname VARCHAR(255) DEFAULT NULL,
+    user_email VARCHAR(255) DEFAULT NULL,
+    user_url VARCHAR(255) DEFAULT NULL,
+    user_desc TEXT,
+    user_default_blog VARCHAR(32) DEFAULT NULL,
+    user_options TEXT,
+    user_lang VARCHAR(5) DEFAULT NULL,
+    user_tz VARCHAR(128) DEFAULT 'UTC' NOT NULL,
+    user_post_status SMALLINT DEFAULT (-2) NOT NULL,
+    user_creadt TIMESTAMP without time zone DEFAULT now() NOT NULL,
+    user_upddt TIMESTAMP without time zone DEFAULT now() NOT NULL,
+    CONSTRAINT dc_fk_user_default_blog FOREIGN KEY (user_default_blog) REFERENCES dc_blog(blog_id) ON UPDATE CASCADE ON DELETE SET NULL,
+    PRIMARY KEY (user_id)
+);
+
+-- DROP TABLE IF EXISTS dc_post;
+CREATE TABLE dc_post (
+    post_id BIGINT NOT NULL,
+    blog_id VARCHAR(32) NOT NULL,
+    user_id VARCHAR(32) NOT NULL,
+    cat_id BIGINT,
+    post_dt TIMESTAMP without time zone DEFAULT now() NOT NULL,
+    post_tz VARCHAR(128) DEFAULT 'UTC' NOT NULL,
+    post_creadt TIMESTAMP without time zone DEFAULT now() NOT NULL,
+    post_upddt TIMESTAMP without time zone DEFAULT now() NOT NULL,
+    post_password VARCHAR(32) DEFAULT NULL,
+    post_type VARCHAR(32) DEFAULT 'post' NOT NULL,
+    post_format VARCHAR(32) DEFAULT 'xhtml' NOT NULL,
+    post_url VARCHAR(255) NOT NULL,
+    post_lang VARCHAR(5) DEFAULT NULL,
+    post_title VARCHAR(255) DEFAULT NULL,
+    post_excerpt TEXT,
+    post_excerpt_xhtml TEXT,
+    post_content TEXT,
+    post_content_xhtml TEXT NOT NULL,
+    post_notes TEXT,
+    post_meta TEXT,
+    post_words TEXT,
+    post_status SMALLINT DEFAULT 0 NOT NULL,
+    post_selected SMALLINT DEFAULT 0 NOT NULL,
+    post_position INTEGER DEFAULT 0 NOT NULL,
+    post_open_comment SMALLINT DEFAULT 0 NOT NULL,
+    post_open_tb SMALLINT DEFAULT 0 NOT NULL,
+    nb_comment INTEGER DEFAULT 0 NOT NULL,
+    nb_trackback INTEGER DEFAULT 0 NOT NULL,
+    UNIQUE (post_url, post_type, blog_id),
+    CONSTRAINT dc_fk_post_blog FOREIGN KEY (blog_id) REFERENCES dc_blog(blog_id) ON UPDATE CASCADE ON DELETE CASCADE,
+    CONSTRAINT dc_fk_post_category FOREIGN KEY (cat_id) REFERENCES dc_category(cat_id) ON UPDATE CASCADE ON DELETE SET NULL,
+    CONSTRAINT dc_fk_post_user FOREIGN KEY (user_id) REFERENCES dc_user(user_id) ON UPDATE CASCADE ON DELETE CASCADE,
+    PRIMARY KEY (post_id)
+);
+
 -- DROP TABLE IF EXISTS dc_comment;
 CREATE TABLE dc_comment (
     comment_id BIGINT NOT NULL,
@@ -121,43 +182,6 @@ CREATE TABLE dc_ping (
     PRIMARY KEY (post_id, ping_url)
 );
 
--- DROP TABLE IF EXISTS dc_post;
-CREATE TABLE dc_post (
-    post_id BIGINT NOT NULL,
-    blog_id VARCHAR(32) NOT NULL,
-    user_id VARCHAR(32) NOT NULL,
-    cat_id BIGINT,
-    post_dt TIMESTAMP without time zone DEFAULT now() NOT NULL,
-    post_tz VARCHAR(128) DEFAULT 'UTC' NOT NULL,
-    post_creadt TIMESTAMP without time zone DEFAULT now() NOT NULL,
-    post_upddt TIMESTAMP without time zone DEFAULT now() NOT NULL,
-    post_password VARCHAR(32) DEFAULT NULL,
-    post_type VARCHAR(32) DEFAULT 'post' NOT NULL,
-    post_format VARCHAR(32) DEFAULT 'xhtml' NOT NULL,
-    post_url VARCHAR(255) NOT NULL,
-    post_lang VARCHAR(5) DEFAULT NULL,
-    post_title VARCHAR(255) DEFAULT NULL,
-    post_excerpt TEXT,
-    post_excerpt_xhtml TEXT,
-    post_content TEXT,
-    post_content_xhtml TEXT NOT NULL,
-    post_notes TEXT,
-    post_meta TEXT,
-    post_words TEXT,
-    post_status SMALLINT DEFAULT 0 NOT NULL,
-    post_selected SMALLINT DEFAULT 0 NOT NULL,
-    post_position INTEGER DEFAULT 0 NOT NULL,
-    post_open_comment SMALLINT DEFAULT 0 NOT NULL,
-    post_open_tb SMALLINT DEFAULT 0 NOT NULL,
-    nb_comment INTEGER DEFAULT 0 NOT NULL,
-    nb_trackback INTEGER DEFAULT 0 NOT NULL,
-    UNIQUE (post_url, post_type, blog_id),
-    CONSTRAINT dc_fk_post_blog FOREIGN KEY (blog_id) REFERENCES dc_blog(blog_id) ON UPDATE CASCADE ON DELETE CASCADE,
-    CONSTRAINT dc_fk_post_category FOREIGN KEY (cat_id) REFERENCES dc_category(cat_id) ON UPDATE CASCADE ON DELETE SET NULL,
-    CONSTRAINT dc_fk_post_user FOREIGN KEY (user_id) REFERENCES dc_user(user_id) ON UPDATE CASCADE ON DELETE CASCADE,
-    PRIMARY KEY (post_id)
-);
-
 -- DROP TABLE IF EXISTS dc_post_media;
 CREATE TABLE dc_post_media (
     media_id BIGINT NOT NULL,
@@ -188,36 +212,11 @@ CREATE TABLE dc_setting (
     UNIQUE (setting_ns, setting_id, blog_id)
 );
 
--- DROP TABLE IF EXISTS dc_user;
-CREATE TABLE dc_user (
-    user_id VARCHAR(32) NOT NULL,
-    user_super SMALLINT,
-    user_status SMALLINT DEFAULT 1 NOT NULL,
-    user_pwd VARCHAR(40) NOT NULL,
-    user_change_pwd SMALLINT DEFAULT 0 NOT NULL,
-    user_recover_key VARCHAR(32) DEFAULT NULL,
-    user_name VARCHAR(255) DEFAULT NULL,
-    user_firstname VARCHAR(255) DEFAULT NULL,
-    user_displayname VARCHAR(255) DEFAULT NULL,
-    user_email VARCHAR(255) DEFAULT NULL,
-    user_url VARCHAR(255) DEFAULT NULL,
-    user_desc TEXT,
-    user_default_blog VARCHAR(32) DEFAULT NULL,
-    user_options TEXT,
-    user_lang VARCHAR(5) DEFAULT NULL,
-    user_tz VARCHAR(128) DEFAULT 'UTC' NOT NULL,
-    user_post_status SMALLINT DEFAULT (-2) NOT NULL,
-    user_creadt TIMESTAMP without time zone DEFAULT now() NOT NULL,
-    user_upddt TIMESTAMP without time zone DEFAULT now() NOT NULL,
-    CONSTRAINT dc_fk_user_default_blog FOREIGN KEY (user_default_blog) REFERENCES dc_blog(blog_id) ON UPDATE CASCADE ON DELETE SET NULL,
-    PRIMARY KEY (user_id)
-);
-
 -- DROP TABLE IF EXISTS dc_version;
 CREATE TABLE dc_version (
     module VARCHAR(64) NOT NULL,
     version VARCHAR(32) NOT NULL,
-    PRIMARY KEY (module);
+    PRIMARY KEY (module)
 );
 
 CREATE INDEX dc_idx_blog_blog_upddt ON dc_blog USING btree (blog_upddt);
